@@ -1,6 +1,6 @@
 import pandas as pd
-from typing import List
-
+from typing import List, Union
+from pandas import DataFrame
 
 
 def load_file(filepath, header=0, as_dataframe=False):
@@ -9,8 +9,8 @@ def load_file(filepath, header=0, as_dataframe=False):
     ext = file_ext(filepath)
 
     if ext == 'csv':
-        df = pd.read_csv(filepath, header=header)
-    elif ext in ['xlsx', 'xls']:
+        df = pd.read_csv(filepath, encoding='utf-8', header=header)
+    elif ext == 'xlsx':
         df = pd.read_excel(filepath, header=header)
     else:
         print("Invalid file format")
@@ -21,17 +21,17 @@ def load_file(filepath, header=0, as_dataframe=False):
 
     return df.to_dict('list')
 
-def write(filepath, items: List[dict], mode='w'):
+def write(filepath, items: Union[List[dict], DataFrame], mode='w'):
     header = True
     if mode == 'a':
         header = False
 
-    ext = file_ext(filepath)
-
-    if ext == 'csv':
+    if isinstance(items, DataFrame):
+        df = items
+    else:
         df = pd.DataFrame(items) 
-        df.to_csv(filepath, index=False, mode=mode, header=header)
 
+    df.to_csv(filepath, index=False, mode=mode, header=header)
 
 def file_ext(filepath):
     filename = filepath.name
